
**Acquire, Organize, and Distribute Software**

Pulp is a platform for managing repositories of content, such as software
packages, and pushing that content out to large numbers of consumers.

Using Pulp you can:
- Locally mirror all or part of a repository
- Host your own content in a new repository
- Manage content from multiple sources in one place
- Promote content through different repos in an organized way

Pulp is completely free and open-source!
- License: GPLv2+
- Documentation: https://docs.pulpproject.org/
- Source: https://github.com/pulp/pulpcore/
- Bugs: https://pulp.plan.io/projects/pulp

For more information, check out the project website: https://pulpproject.org

Get Help
--------

Check out our help page for ways to get help:

https://pulpproject.org/help/
